   #ifndef _MSA_H_
#define _MSA_H_
#define XML_ENCODING "UTF-8"
#define XML_VERSION "1.0"

#define REMOVE_SIGNAL_TEXT "remove"
#define SET_SIGNAL_TEXT "set"
#define _(String) gettext(String)

#define TARGET_TAG "TargetID"
#define TARGET_TAG_ORDER_ATTR "orderNumber"
//#define TARGET_TAG_XPATH "/TransitData/TargetID"
//#define SOURCE_TAG_XPATH "/TransitData/SourceID"
//#include <conicconnection.h>
//#include <conicconnectionevent.h>
#include <conic.h>
#include <libosso.h>
#include <hildon-1/hildon/hildon-program.h>
#include <libintl.h>
#include <gconf/gconf-client.h>
#define PATH_PROXY_HOST "/apps/msa/def_proxy"
#define PATH_PROXY_PORT "/apps/msa/def_port"

#include "msa_module.h"


int MSA_END;

void msa_end();
static int start_module(const char* id, int argc, char** argv);
static int start_connection();
static void msa_connection_handler(ConIcConnection* connection, ConIcConnectionEvent* event, gpointer user_data);
static void msa_get_conic_settings(ConIcConnection* connection, gchar** proxy, gint* port);
static void msa_set_driver_status(msa_module_status _status, gchar* proxy, gint port);
//static int init_event_manager();

#endif

